@@ -10,12 +10,37 @@
 require 'facter/util/macaddress'
 
 Facter.add(:macaddress) do
-  confine :kernel => %w{SunOS Linux GNU/kFreeBSD}
+  confine :kernel => 'Linux'
+  has_weight  10                # about an order of magnitude faster
+  setcode do
+    begin
+      Dir.glob('/sys/class/net/*').reject {|x| x[-3..-1] == '/lo' }.first
+      path and File.read(path + '/address')
+    rescue Exception
+      nil
+    end
+  end
+end
+
+Facter.add(:macaddress) do
+  confine :kernel => 'Linux'
+  setcode do
+    ether = []
+    output = Facter::Util::Resolution.exec("/sbin/ifconfig -a 2>/dev/null")
+    output.each_line do |s|
+      ether.push($1) if s =~ /(?:ether|HWaddr) ((\w{1,2}:){5,}\w{1,2})/
+    end
+    Facter::Util::Macaddress.standardize(ether[0])
+  end
+end
+
+Facter.add(:macaddress) do
+  confine :kernel => %w{SunOS GNU/kFreeBSD}
   setcode do
     ether = []
     output = Facter::Util::Resolution.exec("/sbin/ifconfig -a")
     output.each_line do |s|
-      ether.push($1) if s =~ /(?:ether|HWaddr) (\w{1,2}:\w{1,2}:\w{1,2}:\w{1,2}:\w{1,2}:\w{1,2})/
+      ether.push($1) if s =~ /(?:ether|HWaddr) ((\w{1,2}:){5,}\w{1,2})/
     end
     Facter::Util::Macaddress.standardize(ether[0])
   end
